==> hcfg-1.014.tar.gz: hcfg-1.014/setup.py <==
from distutils.core import setup
setup(
  name = 'hcfg',         # How you named your package folder (MyLib)
  packages = ['hcfg'],   # Chose the same as "name"
  version = '1.014',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Alternative for JSON.',   # Give a short description about your library
  author = 'hyper1923',                   # Type in your name
  author_email = 'hyperamabanyiyen@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/hyper1923/hcfg',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/hyper1923/hcfg/releases/download/sourcecode/hcfg.tar.gz',    # I explain this later on
  keywords = ['JSON', 'PARSER'],   # Keywords that define your package best
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> hcfg-1.025.tar.gz: hcfg-1.025/setup.py <==
from distutils.core import setup
setup(
  name = 'hcfg',         # How you named your package folder (MyLib)
  packages = ['hcfg'],   # Chose the same as "name"
  version = '1.025',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Alternative for JSON.',   # Give a short description about your library
  author = 'hyper1923',                   # Type in your name
  author_email = 'hyperamabanyiyen@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/hyper1923/hcfg',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/hyper1923/hcfg/releases/download/sourcecode/hcfg.tar.gz',    # I explain this later on
  keywords = ['JSON', 'PARSER','DATABASE'],   # Keywords that define your package best
  install_requires=['json'],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
